==> cloudbees-folder-6.1.2-sources.jar: com/cloudbees/hudson/plugins/folder/computed/Messages.java <==
// CHECKSTYLE:OFF

package com.cloudbees.hudson.plugins.folder.computed;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code PseudoRun.DisplayName}: {@code log}.
     * 
     * @return
     *     {@code log}
     */
    public static String PseudoRun_DisplayName() {
        return holder.format("PseudoRun.DisplayName");
    }

    /**
     * Key {@code PseudoRun.DisplayName}: {@code log}.
     * 
     * @return
     *     {@code log}
     */
    public static Localizable _PseudoRun_DisplayName() {
        return new Localizable(holder, "PseudoRun.DisplayName");
    }

    /**
     * Key {@code
     * ThrottleComputationQueueTaskDispatcher.MaxConcurrentIndexing}: {@code
     * At maximum indexing capacity}.
     * 
     * @return
     *     {@code At maximum indexing capacity}
     */
    public static String ThrottleComputationQueueTaskDispatcher_MaxConcurrentIndexing() {
        return holder.format("ThrottleComputationQueueTaskDispatcher.MaxConcurrentIndexing");
    }

    /**
     * Key {@code
     * ThrottleComputationQueueTaskDispatcher.MaxConcurrentIndexing}: {@code
     * At maximum indexing capacity}.
     * 
     * @return
     *     {@code At maximum indexing capacity}
     */
    public static Localizable _ThrottleComputationQueueTaskDispatcher_MaxConcurrentIndexing() {
        return new Localizable(holder, "ThrottleComputationQueueTaskDispatcher.MaxConcurrentIndexing");
    }

    /**
     * Key {@code FolderComputation.DisplayName}: {@code Folder Computation}.
     * 
     * @return
     *     {@code Folder Computation}
     */
    public static String FolderComputation_DisplayName() {
        return holder.format("FolderComputation.DisplayName");
    }

    /**
     * Key {@code FolderComputation.DisplayName}: {@code Folder Computation}.
     * 
     * @return
     *     {@code Folder Computation}
     */
    public static Localizable _FolderComputation_DisplayName() {
        return new Localizable(holder, "FolderComputation.DisplayName");
    }

    /**
     * Key {@code PeriodicFolderTrigger.DisplayName}: {@code Periodically if
     * not otherwise run}.
     * 
     * @return
     *     {@code Periodically if not otherwise run}
     */
    public static String PeriodicFolderTrigger_DisplayName() {
        return holder.format("PeriodicFolderTrigger.DisplayName");
    }

    /**
     * Key {@code PeriodicFolderTrigger.DisplayName}: {@code Periodically if
     * not otherwise run}.
     * 
     * @return
     *     {@code Periodically if not otherwise run}
     */
    public static Localizable _PeriodicFolderTrigger_DisplayName() {
        return new Localizable(holder, "PeriodicFolderTrigger.DisplayName");
    }

    /**
     * Key {@code ComputedFolder.already_computing}: {@code Already
     * computing}.
     * 
     * @return
     *     {@code Already computing}
     */
    public static String ComputedFolder_already_computing() {
        return holder.format("ComputedFolder.already_computing");
    }

    /**
     * Key {@code ComputedFolder.already_computing}: {@code Already
     * computing}.
     * 
     * @return
     *     {@code Already computing}
     */
    public static Localizable _ComputedFolder_already_computing() {
        return new Localizable(holder, "ComputedFolder.already_computing");
    }

}

==> cloudbees-folder-6.7-sources.jar: com/cloudbees/hudson/plugins/folder/computed/Messages.java <==
// CHECKSTYLE:OFF

package com.cloudbees.hudson.plugins.folder.computed;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;
import org.kohsuke.accmod.Restricted;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
@Restricted(org.kohsuke.accmod.restrictions.NoExternalUse.class)
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code ComputedFolder.ComputationInProgress}: {@code Recomputation
     * is currently in progress}.
     * 
     * @return
     *     {@code Recomputation is currently in progress}
     */
    public static String ComputedFolder_ComputationInProgress() {
        return holder.format("ComputedFolder.ComputationInProgress");
    }

    /**
     * Key {@code ComputedFolder.ComputationInProgress}: {@code Recomputation
     * is currently in progress}.
     * 
     * @return
     *     {@code Recomputation is currently in progress}
     */
    public static Localizable _ComputedFolder_ComputationInProgress() {
        return new Localizable(holder, "ComputedFolder.ComputationInProgress");
    }

    /**
     * Key {@code PseudoRun.DisplayName}: {@code log}.
     * 
     * @return
     *     {@code log}
     */
    public static String PseudoRun_DisplayName() {
        return holder.format("PseudoRun.DisplayName");
    }

    /**
     * Key {@code PseudoRun.DisplayName}: {@code log}.
     * 
     * @return
     *     {@code log}
     */
    public static Localizable _PseudoRun_DisplayName() {
        return new Localizable(holder, "PseudoRun.DisplayName");
    }

    /**
     * Key {@code
     * ThrottleComputationQueueTaskDispatcher.MaxConcurrentIndexing}: {@code
     * At maximum indexing capacity}.
     * 
     * @return
     *     {@code At maximum indexing capacity}
     */
    public static String ThrottleComputationQueueTaskDispatcher_MaxConcurrentIndexing() {
        return holder.format("ThrottleComputationQueueTaskDispatcher.MaxConcurrentIndexing");
    }

    /**
     * Key {@code
     * ThrottleComputationQueueTaskDispatcher.MaxConcurrentIndexing}: {@code
     * At maximum indexing capacity}.
     * 
     * @return
     *     {@code At maximum indexing capacity}
     */
    public static Localizable _ThrottleComputationQueueTaskDispatcher_MaxConcurrentIndexing() {
        return new Localizable(holder, "ThrottleComputationQueueTaskDispatcher.MaxConcurrentIndexing");
    }

    /**
     * Key {@code FolderComputation.DisplayName}: {@code Folder Computation}.
     * 
     * @return
     *     {@code Folder Computation}
     */
    public static String FolderComputation_DisplayName() {
        return holder.format("FolderComputation.DisplayName");
    }

    /**
     * Key {@code FolderComputation.DisplayName}: {@code Folder Computation}.
     * 
     * @return
     *     {@code Folder Computation}
     */
    public static Localizable _FolderComputation_DisplayName() {
        return new Localizable(holder, "FolderComputation.DisplayName");
    }

    /**
     * Key {@code PeriodicFolderTrigger.DisplayName}: {@code Periodically if
     * not otherwise run}.
     * 
     * @return
     *     {@code Periodically if not otherwise run}
     */
    public static String PeriodicFolderTrigger_DisplayName() {
        return holder.format("PeriodicFolderTrigger.DisplayName");
    }

    /**
     * Key {@code PeriodicFolderTrigger.DisplayName}: {@code Periodically if
     * not otherwise run}.
     * 
     * @return
     *     {@code Periodically if not otherwise run}
     */
    public static Localizable _PeriodicFolderTrigger_DisplayName() {
        return new Localizable(holder, "PeriodicFolderTrigger.DisplayName");
    }

    /**
     * Key {@code ComputedFolder.already_computing}: {@code Already
     * computing}.
     * 
     * @return
     *     {@code Already computing}
     */
    public static String ComputedFolder_already_computing() {
        return holder.format("ComputedFolder.already_computing");
    }

    /**
     * Key {@code ComputedFolder.already_computing}: {@code Already
     * computing}.
     * 
     * @return
     *     {@code Already computing}
     */
    public static Localizable _ComputedFolder_already_computing() {
        return new Localizable(holder, "ComputedFolder.already_computing");
    }

}
